package com.yonge.cooleshow.admin.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.yonge.cooleshow.auth.api.client.SysUserFeignService;
import com.yonge.cooleshow.auth.api.entity.SysUser;
import com.yonge.cooleshow.biz.dal.dao.SubjectDao;
import com.yonge.cooleshow.biz.dal.entity.Teacher;
import com.yonge.cooleshow.biz.dal.service.TeacherService;
import com.yonge.cooleshow.biz.dal.support.Condition;
import com.yonge.cooleshow.biz.dal.support.Query;
import com.yonge.cooleshow.biz.dal.vo.TeacherHomeVo;
import com.yonge.cooleshow.common.controller.BaseController;
import com.yonge.cooleshow.common.entity.HttpResponseResult;
import com.yonge.toolset.utils.string.StringUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import java.util.List;

@RestController
@RequestMapping("/Teacher")
@Api(value = "教师表", tags = "教师表")
public class TeacherController extends BaseController {

    @Autowired
    private TeacherService teacherService;

    /**
     * 查询单条
     */
    @GetMapping("/detail")
    @ApiOperation(value = "详情", notes = "传入teacher")
    public HttpResponseResult<Teacher> detail(Teacher teacher) {
        Teacher detail = teacherService.getOne(Condition.getQueryWrapper(teacher));
        return succeed(detail);
    }

    /**
     * 查询集合
     */
    @GetMapping("/list")
    @ApiOperation(value = "查询集合", notes = "传入teacher")
    public HttpResponseResult<List<Teacher>> list(Teacher teacher) {
        List<Teacher> list = teacherService.list();
        return succeed(list);
    }

    /**
     * 查询分页
     */
    @GetMapping("/page")
    @ApiOperation(value = "查询分页", notes = "传入teacher")
    public HttpResponseResult<IPage<Teacher>> page(Teacher teacher, Query query) {
        IPage<Teacher> pages = teacherService.selectPage(Condition.getPage(query), teacher);
        return succeed(pages);
    }

    /**
     * 新增
     */
    @PostMapping("/save")
    @ApiOperation(value = "新增", notes = "传入teacher")
    public HttpResponseResult save(@Valid @RequestBody Teacher teacher) {
        return status(teacherService.save(teacher));
    }

    /**
     * 修改
     */
    @PostMapping("/update")
    @ApiOperation(value = "修改", notes = "传入teacher")
    public HttpResponseResult update(@Valid @RequestBody Teacher teacher) {
        return status(teacherService.updateById(teacher));
    }

    /**
     * 新增或修改
     */
    @PostMapping("/submit")
    @ApiOperation(value = "新增或修改", notes = "传入teacher")
    public HttpResponseResult submit(@RequestBody Teacher teacher) {
        return status(teacherService.saveOrUpdate(teacher));
    }

    /**
     * 删除
     */
    @PostMapping("/remove")
    @ApiOperation(value = "逻辑删除", notes = "传入ids")
    public HttpResponseResult remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
        if (StringUtil.isEmpty(ids)) {
            return failed("参数不能为空");
        }
        return status(teacherService.removeByIds(StringUtil.toLongList(ids)));
    }


}