package com.yonge.cooleshow.biz.dal.support;

import com.baomidou.mybatisplus.core.metadata.IPage;

import java.io.Serializable;
import java.util.Collections;
import java.util.List;

/**
 * 分页模型
 *
 * @author Chill
 */
public class BasePage<T> implements Serializable {

	private static final long serialVersionUID = 1L;

	/**
	 * 查询数据列表
	 */
	private List<T> records = Collections.emptyList();

	/**
	 * 总数
	 */
	private long total = 0;
	/**
	 * 每页显示条数，默认 10
	 */
	private long size = 10;

	/**
	 * 当前页
	 */
	private long current = 1;

	public static long getSerialVersionUID() {
		return serialVersionUID;
	}

	public List<T> getRecords() {
		return records;
	}

	public void setRecords(List<T> records) {
		this.records = records;
	}

	public long getTotal() {
		return total;
	}

	public void setTotal(long total) {
		this.total = total;
	}

	public long getSize() {
		return size;
	}

	public void setSize(long size) {
		this.size = size;
	}

	public long getCurrent() {
		return current;
	}

	public void setCurrent(long current) {
		this.current = current;
	}

	/**
	 * mybatis-plus分页模型转化
	 *
	 * @param page 分页实体类
	 * @return BasePage<T>
	 */
	public static <T> BasePage<T> of(IPage<T> page) {
		BasePage<T> basePage = new BasePage<>();
		basePage.setRecords(page.getRecords());
		basePage.setTotal(page.getTotal());
		basePage.setSize(page.getSize());
		basePage.setCurrent(page.getCurrent());
		return basePage;
	}

}
