package com.yonge.cooleshow.teacher.controller;

import java.util.List;
import com.baomidou.mybatisplus.core.metadata.IPage;

import com.yonge.cooleshow.auth.api.client.SysUserFeignService;
import com.yonge.cooleshow.auth.api.entity.SysUser;
import com.yonge.cooleshow.biz.dal.support.Condition;
import com.yonge.cooleshow.biz.dal.support.Query;
import com.yonge.cooleshow.common.controller.BaseController;
import com.yonge.cooleshow.common.entity.HttpResponseResult;
import com.yonge.toolset.utils.string.StringUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;

import com.yonge.cooleshow.biz.dal.entity.TeacherAuthMusicianRecord;
import com.yonge.cooleshow.biz.dal.service.TeacherAuthMusicianRecordService;

@RestController
@RequestMapping("/TeacherAuthMusicianRecord")
@Api(value = "老师音乐人审核表", tags = "老师音乐人审核表")
public class TeacherAuthMusicianRecordController extends BaseController {

    @Autowired
    private TeacherAuthMusicianRecordService teacherAuthMusicianRecordService;
	@Autowired
	private SysUserFeignService sysUserFeignService;

	/**
	 * 获取音乐人审核状态
	 */
	@GetMapping("/getMusicianAuthStatus")
	@ApiOperation(value = "获取音乐人审核状态")
	public HttpResponseResult<Integer> getMusicianAuthStatus() {
		SysUser user = sysUserFeignService.queryUserInfo();
		if (user == null) {
			return failed(HttpStatus.FORBIDDEN, "请登录");
		}
		Integer musicianAuthStatus = teacherAuthMusicianRecordService.getMusicianAuthStatus(user.getId());

		return succeed(musicianAuthStatus);
	}

	@PostMapping("/doApply")
	@ApiOperation(value = "提交申请", notes = "传入teacherAuthEntryRecord")
	public HttpResponseResult<Boolean> doApply(){
		SysUser sysUser = sysUserFeignService.queryUserInfo();
		//处理老师申请逻辑
		return teacherAuthMusicianRecordService.doApply(sysUser.getId());
	}


	/**
     * 查询单条
     */
    @GetMapping("/detail")
    @ApiOperation(value = "详情", notes = "传入teacherAuthMusicianRecord")
    public HttpResponseResult<TeacherAuthMusicianRecord> detail(TeacherAuthMusicianRecord teacherAuthMusicianRecord) {
		TeacherAuthMusicianRecord detail = teacherAuthMusicianRecordService.getOne(Condition.getQueryWrapper(teacherAuthMusicianRecord));
		return succeed(detail);
	}
    
    
    /**
     * 查询集合
     */
    @GetMapping("/list")
    @ApiOperation(value = "查询集合", notes = "传入teacherAuthMusicianRecord")
    public HttpResponseResult<List<TeacherAuthMusicianRecord>> list(TeacherAuthMusicianRecord teacherAuthMusicianRecord) {
		List<TeacherAuthMusicianRecord> list = teacherAuthMusicianRecordService.list();
		return succeed(list);
	}
    
    /**
     * 查询分页
     */
    @GetMapping("/page")
    @ApiOperation(value = "查询分页", notes = "传入teacherAuthMusicianRecord")
    public HttpResponseResult<IPage<TeacherAuthMusicianRecord>> page(TeacherAuthMusicianRecord teacherAuthMusicianRecord, Query query) {
		IPage<TeacherAuthMusicianRecord> pages = teacherAuthMusicianRecordService.selectPage(Condition.getPage(query), teacherAuthMusicianRecord);
		return succeed(pages);
	}
    
    /**
	 * 新增
	 */
	@PostMapping("/save")
	@ApiOperation(value = "新增", notes = "传入teacherAuthMusicianRecord")
	public HttpResponseResult save(@Valid @RequestBody TeacherAuthMusicianRecord teacherAuthMusicianRecord) {
    	return status(teacherAuthMusicianRecordService.save(teacherAuthMusicianRecord));
	}
    
    /**
	 * 修改
	 */
	@PostMapping("/update")
	@ApiOperation(value = "修改", notes = "传入teacherAuthMusicianRecord")
	public HttpResponseResult update(@Valid @RequestBody TeacherAuthMusicianRecord teacherAuthMusicianRecord) {
        return status(teacherAuthMusicianRecordService.updateById(teacherAuthMusicianRecord));
	}
    
    /**
	 * 新增或修改
	 */
    @PostMapping("/submit")
    @ApiOperation(value = "新增或修改", notes = "传入teacherAuthMusicianRecord")
	public HttpResponseResult submit(@RequestBody TeacherAuthMusicianRecord teacherAuthMusicianRecord) {
        return status(teacherAuthMusicianRecordService.saveOrUpdate(teacherAuthMusicianRecord));
    }

 	/**
	 * 删除
	 */
	@PostMapping("/remove")
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public HttpResponseResult remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
        if (StringUtil.isEmpty(ids)) {
			return failed("参数不能为空");
		}
		return status(teacherAuthMusicianRecordService.removeByIds(StringUtil.toLongList(ids)));
	}
}