package com.yonge.cooleshow.teacher.controller;

import com.yonge.cooleshow.biz.dal.dto.req.TeacherSetReq;
import com.yonge.cooleshow.biz.dal.vo.TeacherHomeVo;
import com.yonge.cooleshow.biz.dal.vo.TeacherVo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.*;

import com.yonge.cooleshow.auth.api.client.SysUserFeignService;
import com.yonge.cooleshow.auth.api.entity.SysUser;
import com.yonge.cooleshow.biz.dal.entity.Teacher;
import com.yonge.cooleshow.biz.dal.service.TeacherService;
import com.yonge.cooleshow.common.controller.BaseController;
import com.yonge.cooleshow.common.entity.HttpResponseResult;

@RestController
@RequestMapping("/Teacher")
@Api(value = "教师表", tags = "教师表")
public class TeacherController extends BaseController {

    @Autowired
    private TeacherService teacherService;

    @Autowired
    private SysUserFeignService sysUserFeignService;

    @ApiOperation(value = "我的-查询教师基本信息")
    @GetMapping("/queryUserInfo")
    public HttpResponseResult<TeacherHomeVo> queryUserInfo() {
        SysUser user = sysUserFeignService.queryUserInfo();
        if (user == null) {
            return failed(HttpStatus.FORBIDDEN, "请登录");
        }
        Teacher teacher = teacherService.getById(user.getId());
		TeacherHomeVo teacherHomeVo = new TeacherHomeVo();
		teacherHomeVo.setHeardUrl(user.getAvatar());
		teacherHomeVo.setUsername(user.getUsername());
		//todo 老师授课信息
		teacherHomeVo.setStarGrade(1);
		teacherHomeVo.setFansNum(1);
		teacherHomeVo.setExpTime(1);
		teacherHomeVo.setUnExpTime(1);

		teacherHomeVo.setEntryStatus(teacher.getEntryStatus());
		return succeed(teacherHomeVo);
    }

    @ApiOperation(value = "判断老师直播权限")
    @GetMapping("/checkLiveAuth")
    public HttpResponseResult<Boolean> checkLiveAuth(){
        SysUser user = sysUserFeignService.queryUserInfo();
        if (user == null) {
            return failed(HttpStatus.FORBIDDEN, "请登录");
        }
        //todo 根据老师规则，判断老师直播权限
        return HttpResponseResult.succeed(true);
    }

    @GetMapping("/getSetDetail")
    @ApiOperation(value = "获取设置详情")
    public HttpResponseResult<TeacherVo> getSetDetail() {
        SysUser user = sysUserFeignService.queryUserInfo();
        if (user == null) {
            return failed(HttpStatus.FORBIDDEN, "请登录");
        }
        TeacherVo detail = teacherService.getSetDetail(user.getId());
        return succeed(detail);
    }

    @PostMapping("/submitSetDetail")
    @ApiOperation(value = "修改设置信息", notes = "传入teacher")
    public HttpResponseResult<TeacherVo> submitSetDetail(@RequestBody TeacherSetReq setReq) {
        SysUser user = sysUserFeignService.queryUserInfo();
        if (user == null) {
            return failed(HttpStatus.FORBIDDEN, "请登录");
        }
        //设置
        teacherService.submitSetDetail(setReq,user.getId());
        return succeed(teacherService.getSetDetail(user.getId()));
    }


}